@@ -8,9 +8,12 @@ sub write_out {
     my $config = shift;
     my $feed = shift;
     my $summary = shift;
+    my $reverse = shift;
 
     my $query = $feed->{'query'};
     my $hash = $feed->{'feed'};
+    my $group_map = ($config->{'group_map'}) ? $hash->{'group_map'} : undef;
+
     my $created = $hash->{'created'} || $hash->{'detecttime'};
     my $feedid = $hash->{'id'};
     my @a = @{$hash->{'entry'}};
@@ -24,12 +27,13 @@ sub write_out {
     }
     push(@cols,(
         'restriction',
+        'guid',
         'severity',
         'confidence',
         'detecttime',
     ));
     unless($summary){
-        my $t = $a[0];
+        my $t = $a[$#a];
         if(exists($t->{'address'})){
             push(@cols,('address'));
         }
@@ -48,7 +52,9 @@ sub write_out {
         if(exists($t->{'rir'})){
             push(@cols,'rir');
         }
-        if(exists($t->{'md5'})){
+        if(exists($t->{'malware_md5'})){
+            push(@cols,('malware_md5','malware_sha1'));
+        } elsif(exists($t->{'md5'}) && $t->{'impact'} ne 'malware'){
             push(@cols,('md5','sha1'));
         } 
         if(exists($t->{'cc'})){
@@ -63,8 +69,8 @@ sub write_out {
             'alternativeid',
         ));
    }
-   if($self->{'fields'}){
-        @cols = @{$self->{'fields'}};
+   if($config->{'fields'}){
+        @cols = @{$config->{'fields'}};
     }
     if(my $c = $self->{'config'}->{'display'}){
         @cols = @$c;
@@ -74,11 +80,14 @@ sub write_out {
     pop(@header);
     my $table = Text::Table->new(@header);
 
-    my @sorted = sort { $a->{'detecttime'} cmp $b->{'detecttime'} } @a;
     if(my $max = $self->{'max_desc'}){
-        map { $_->{'description'} = substr($_->{'description'},0,$max) } @sorted;
+        map { $_->{'description'} = substr($_->{'description'},0,$max) } @a;
     }
-    foreach my $r (@sorted){
+    if($group_map){
+        map { $_->{'guid'} = $group_map->{$_->{'guid'}} } @a;
+    }
+    @a = reverse(@a) if($reverse);
+    foreach my $r (@a){
         $table->load([ map { $r->{$_} } @cols]);
     }
     if($created){
